@@ -1,6 +1,6 @@
 # encoding: utf-8
 #  Phusion Passenger - https://www.phusionpassenger.com/
-#  Copyright (c) 2010-2015 Phusion Holding B.V.
+#  Copyright (c) 2010-2017 Phusion Holding B.V.
 #
 #  "Passenger", "Phusion Passenger" and "Union Station" are registered
 #  trademarks of Phusion Holding B.V.
@@ -30,14 +30,19 @@ module PhusionPassenger
   ###### Names and version numbers ######
 
   PACKAGE_NAME = 'passenger'
-  # Run 'rake src/cxx_supportlib/Constants.h' after changing this number.
-  VERSION_STRING = '5.0.25'
+  # Run 'rake src/cxx_supportlib/Constants.h configkit_schemas_inline_comments' after changing this number.
+  VERSION_STRING = '5.2.1'
 
-  PREFERRED_NGINX_VERSION = '1.8.1'
-  NGINX_SHA256_CHECKSUM = '8f4b3c630966c044ec72715754334d1fdf741caa1d5795fb4646c27d09f797b7'
+  PREFERRED_NGINX_VERSION = '1.12.2'
+  NGINX_SHA256_CHECKSUM = '305f379da1d5fb5aefa79e45c829852ca6983c7cd2a79328f8e084a324cf0416'
 
-  PREFERRED_PCRE_VERSION  = '8.34'
-  PCRE_SHA256_CHECKSUM = '1dd78994c81e44ac41cf30b2a21d4b4cc6d76ccde7fc6e77713ed51d7bddca47'
+  # Packaging may be locked to an older version due to the specific module configuration being
+  # incompatible with the version we prefer (latest stable).
+  PACKAGING_PREFERRED_NGINX_VERSION = '1.12.2'
+  PACKAGING_NGINX_SHA256_CHECKSUM = '305f379da1d5fb5aefa79e45c829852ca6983c7cd2a79328f8e084a324cf0416'
+
+  PREFERRED_PCRE_VERSION  = '8.41'
+  PCRE_SHA256_CHECKSUM = '244838e1f1d14f7e2fa7681b857b3a8566b74215f28133f14a8f5e59241b682c'
 
   STANDALONE_INTERFACE_VERSION  = 1
 
@@ -168,7 +173,7 @@ module PhusionPassenger
 
   # Whether the current Phusion Passenger installation is installed
   # from a release package, e.g. an official gem or official tarball.
-  # Retruns false if e.g. the gem was built by the user, or if this
+  # Returns false if e.g. the gem was built by the user, or if this
   # install is from a git repository.
   def self.installed_from_release_package?
     File.exist?("#{resources_dir}/release.txt")
@@ -235,6 +240,20 @@ module PhusionPassenger
     require("#{ruby_libdir}/phusion_passenger/#{name}")
   end
 
+  # Forward define public_api.rb methods for code that tries to hook
+  # Passenger events before an app is spawned (such as mongoid)
+  def self.on_event(name, &block)
+    # The definition in `public_api.rb` will override this implementation when
+    # a Ruby application is spawned.
+    nil
+  end
+
+  def self.call_event(name, *args)
+    # The definition in `public_api.rb` will override this implementation when
+    # a Ruby application is spawned.
+    nil
+  end
+
 
 private
   def self.infer_install_spec
@@ -306,7 +325,12 @@ private
     end
     if home.nil? || home.empty?
       require 'etc' if !defined?(Etc)
-      home = Etc.getpwuid(Process.uid).dir
+      begin
+        home = Etc.getpwuid(Process.uid).dir
+      rescue ArgumentError
+        # Unknown user.
+        home = ENV['HOME']
+      end
     end
     return home
   end
